const Config = {
  Screen: {
    Width: 480,
    Height: 720,
    BackGroundColor: 0x000000,
  }
}

let core;
window.onload = () => {
  core = new Game(Config.Screen.Width, Config.Screen.Height, Config.Screen.BackGroundColor);
  core.replaceScene(new MainScene());
}

class MainScene extends Container {
  constructor(){
    super();
    this.interactive = true;

    const bg = new Sprite();
    bg.width = Config.Screen.Width; 
    bg.height = Config.Screen.Height
    this.addChild(bg);
    
    //火花の色
    const pallet = [0x1D2B53, 0x7E2553, 0x008751, 0xAB5236, 0x5F574F, 0xC2C3C7, 0xFF004D, 0xFFA300, 0xFFEC27, 0x00E436, 0x29ADFF, 0x83769C, 0xFF77A8, 0xFFCCAA];

    this.on('pointerdown', (event) => {
      const texture = createStarTexture(random(3, 9), 16, 4);
      const max = random(5, 35);
      const color = pallet[random(0, pallet.length-1)];
      const speed = random(3, 10);
      const pos = event.data.getLocalPosition(this);
      for(let i = 0; i < max; i++){
        const s = new Spark();
        s.texture = texture;
        const rad = Math.PI * 2 / max * i;
        s.vx = Math.cos(rad) * speed;
        s.vy = Math.sin(rad) * speed;
        s.tint = color;
        s.position.set(pos.x, pos.y);
        this.addChild(s);
      }
    });
  }
}

//火花のクラス
class Spark extends Sprite {
  constructor(){
    super();
    this.anchor.set(0.5, 0.5);
  }
  update(delta){
    super.update(delta);
    this.rotation += 0.1;
    this.alpha -= 0.01;
    this.scale.x -= 0.003;
    this.scale.y -= 0.003;
    this.x += this.vx;
    this.y += this.vy;
    this.vx *= 0.97;
    this.vy *= 0.97;
    if(this.alpha < 0.01){
      this.destroy();
    }
  }
}

//minからmaxの範囲でランダムな整数を返す
function random(min, max){
	return Math.floor(Math.random() * (max - min + 1)) + min;
}

//星型のテクスチャーを作る
function createStarTexture(points, outerRadius, innerRadius){
  if(points < 3){
    points = 3;//3未満だと勝手に3にする
  }
  let step = (Math.PI * 2) / points;//角度
  let halfStep = step / 2;
  const data = [];
  let dx, dy;
    
  for (let n = 1; n <= points; ++n) {
    dx = Math.cos(step * n - halfStep) * innerRadius;
    dy = Math.sin(step * n - halfStep) * innerRadius;
    data.push(dx, dy);
    dx = Math.cos(step * n) * outerRadius;
    dy = Math.sin(step * n) * outerRadius;
    data.push(dx, dy);
  }
  
  //グラフィックを作る
  const g = new PIXI.Graphics();
  g.beginFill(0xFFFFFF);
  g.drawPolygon(data);
  g.endFill();
  g.x = g.width * 0.5;
  g.y = g.height * 0.5;
  //グラフィックをテクスチャーに
  const texture = PIXI.RenderTexture.create({width: g.width, height: g.height});
  core.app.renderer.render(g, texture);
  
  return texture;
}